PerfCalc

Struct PerfCalc 

pub struct PerfCalc { /* private fields */ }
Builder for configuring and running the performance calculation algorithm This builder is used to configure the number of iterations and the convergence threshold. The default settings are:

  • Maximum iterations: 100
  • Convergence threshold: 1e-6

Example

use nypc_perf::{BattleResult, PerfCalc, Rating};
let mut perf = vec![Rating::new(0.0); 2];
let battles = vec![
    BattleResult {
        i: 0,
        j: 1,
        wij: 2.0,
        wji: 1.0,
    }
];

let calc = PerfCalc::new().max_iters(100).epsilon(1e-6);
calc.run(&mut perf, &battles);

Implementations

Source

impl PerfCalc

pub fn new() -> Self

Creates a new PerfCalc with default settings.

The default settings are:

  • Maximum iterations: 100
  • Convergence threshold: 1e-6
pub fn max_iters(self, max_iterations: usize) -> Self

Sets the maximum number of iterations.

pub fn epsilon(self, epsilon: f64) -> Self

Sets the convergence threshold.

use nypc_perf::PerfCalc;

let calc = PerfCalc::new().epsilon(1e-6);
pub fn run( self, perf: &mut [Rating], battles: &[BattleResult], ) -> Result<usize, f64>

Runs the iterative algorithm to calculate performance ratings.

Arguments
  • perf - Current performance rating values
  • battles - Iterator of battle results
Returns

Ok(iterations) if convergence is reached within max_iterations, or Err(final_error) if not converged.