pub struct Rating {
pub fixed: bool,
pub value: f64,
}Expand description
Represents a player’s rating. If fixed, the value is fixed and cannot be changed. If not fixed, the value is a variable and can be changed. The value is the log-performance rating of the player.
Fields
fixed: boolvalue: f64Implementations